==> vod-common-1.0.1-sources.jar: com/valor/vod/common/tools/http/HttpConstant.java <==
package com.valor.vod.common.tools.http;

/**
 * Created by Frank.Huang on 2016/6/29.
 */
public class HttpConstant {
    public static final String HTTP_TRACE_ID = "traceId";

    public static final String HTTP_REQ_ATTR_TS = "_ts";
    public static final String HTTP_REQ_ATTR_DID = "_did";
    public static final String HTTP_REQ_ATTR_UID = "_uid";
    public static final String HTTP_REQ_ATTR_ACCOUNT_ID = "_accountId";
    public static final String HTTP_REQ_ATTR_ROOT_NODE_ID = "_rootNodeId";
    public static final String HTTP_REQ_ATTR_PRODUCT_ID = "_productId";
    public static final String HTTP_REQ_ATTR_UPROP = "_uprop";
    public static final String HTTP_REQ_ATTR_USER_KEY = "_userKey";
    public static final String HTTP_REQ_ATTR_TOKEN = "_token";

    public static final String HTTP_REQ_ATTR_RET_CODE = "_retcode";
    public static final String HTTP_REQ_ATTR_ERR_CODE = "_errcode";
    public static final String HTTP_REQ_ATTR_RET_MSG = "_errmsg";
    public static final String HTTP_REQ_ATTR_REFER = "_refer";

    public static final String HTTP_ARG_TOKEN = "token";
    public static final String HTTP_ARG_ACT_KEY = "actKey";
    public static final String HTTP_ARG_SESSION_KEY = "sessionKey";
    public static final String HTTP_ARG_DID = "did";
    public static final String HTTP_ARG_UID = "uid";
    public static final String HTTP_ARG_ACCOUNT_ID = "accountId";
    public static final String HTTP_ARG_ACCOUNT_TYPE = "accountType";
    public static final String HTTP_ARG_CLIENT_SESSION = "clientSession";

}

==> vod-common-1.0.2-sources.jar: com/valor/vod/common/tools/http/HttpConstant.java <==
package com.valor.vod.common.tools.http;

/**
 * @author Frank.Huang
 * @date 2016/6/29
 */
public class HttpConstant {
    public static final String HTTP_TRACE_ID = "traceId";

    public static final String HTTP_REQ_ATTR_TS = "_ts";
    public static final String HTTP_REQ_ATTR_DID = "_did";
    public static final String HTTP_REQ_ATTR_UID = "_uid";
    public static final String HTTP_REQ_ATTR_ACCOUNT_ID = "_accountId";
    public static final String HTTP_REQ_ATTR_ROOT_NODE_ID = "_rootNodeId";
    public static final String HTTP_REQ_ATTR_PRODUCT_ID = "_productId";
    public static final String HTTP_REQ_ATTR_UPROP = "_uprop";
    public static final String HTTP_REQ_ATTR_USER_KEY = "_userKey";
    public static final String HTTP_REQ_ATTR_TOKEN = "_token";
    public static final String HTTP_REQ_ATTR_LANG = "_lang";
    public static final String HTTP_REQ_ATTR_VNO = "_vno";
    public static final String HTTP_REQ_ATTR_BRAND = "_brand";
    public static final String HTTP_REQ_ATTR_APP_ID = "_appId";
    public static final String HTTP_REQ_ATTR_APP_VER = "_appVer";
    public static final String HTTP_REQ_ATTR_CLIENT_IP = "_clientIp";

    public static final String HTTP_REQ_ATTR_RET_CODE = "_retcode";
    public static final String HTTP_REQ_ATTR_ERR_CODE = "_errcode";
    public static final String HTTP_REQ_ATTR_RET_MSG = "_errmsg";
    public static final String HTTP_REQ_ATTR_REFER = "_refer";

    public static final String HTTP_ARG_TOKEN = "token";
    public static final String HTTP_ARG_ACT_KEY = "actKey";
    public static final String HTTP_ARG_SESSION_KEY = "sessionKey";
    public static final String HTTP_ARG_DID = "did";
    public static final String HTTP_ARG_UID = "uid";
    public static final String HTTP_ARG_ACCOUNT_ID = "accountId";
    public static final String HTTP_ARG_ACCOUNT_TYPE = "accountType";
    public static final String HTTP_ARG_CLIENT_SESSION = "clientSession";
}
